@@ -112,20 +112,19 @@ class TestCoordinateTransform:
         def check(rc, azc, elc, outc, squeeze=False, strict_dims=False):
             assert (
                 georef.spherical_to_xyz(
-                    rc, azc, elc, self.csite, squeeze=squeeze, strict_dims=strict_dims,
+                    rc, azc, elc, self.csite, squeeze=squeeze, strict_dims=strict_dims
                 )[0].shape
                 == outc
             )
 
         check(np.arange(10), np.arange(36), 10.0, (1, 36, 10, 3))
-        check(np.arange(10), np.arange(36), np.arange(36), (1, 36, 10, 3,))
-        check(np.arange(10), np.arange(36), np.arange(36), (36, 10, 3,), squeeze=True)
+        check(np.arange(10), np.arange(36), np.arange(36), (1, 36, 10, 3))
+        check(np.arange(10), np.arange(36), np.arange(36), (36, 10, 3), squeeze=True)
         check(
             np.arange(10),
             np.arange(36),
             np.arange(36),
             (36, 36, 10, 3),
-            squeeze=None,
             strict_dims=True,
         )
         check(np.arange(10), np.arange(36), np.arange(18), (18, 36, 10, 3))
@@ -136,7 +135,7 @@ class TestCoordinateTransform:
         r, phi = np.meshgrid(np.arange(10), np.arange(36))
         check(r, phi, np.arange(18), (18, 36, 10, 3))
         r, phi = np.meshgrid(np.arange(10), np.arange(36))
-        check(r, phi, np.arange(36), (36, 36, 10, 3,), strict_dims=True)
+        check(r, phi, np.arange(36), (36, 36, 10, 3), strict_dims=True)
         check(10, 36, 10.0, (1, 1, 1, 3))
         check(np.arange(10), 36, 10.0, (1, 1, 10, 3))
         check(10, np.arange(36), 10.0, (1, 36, 1, 3))
@@ -156,7 +155,7 @@ class TestCoordinateTransform:
         )
         re = georef.get_earth_radius(self.csite[1])
         coords, rad = georef.spherical_to_xyz(
-            self.r, self.az, self.th, self.csite, re=re, squeeze=True,
+            self.r, self.az, self.th, self.csite, re=re, squeeze=True
         )
         np.testing.assert_allclose(
             coords[..., 0], self.result_xyz[0], rtol=2e-10, atol=3e-5
@@ -707,15 +706,15 @@ class TestPixMap:
 @requires_data
 class TestGdal:
     if has_data:
-        filename = "geo/bonn_new.tif"
-        geofile = util.get_wradlib_data_file(filename)
-        ds = wradlib.io.open_raster(geofile)
+        filename1 = "geo/bonn_new.tif"
+        geofile1 = util.get_wradlib_data_file(filename1)
+        ds = wradlib.io.open_raster(geofile1)
         (data, coords, proj) = georef.extract_raster_dataset(ds)
 
-        filename = "hdf5/belgium.comp.hdf"
-        geofile = util.get_wradlib_data_file(filename)
-        ds2 = wradlib.io.open_raster(geofile)
-        (data2, coords2, proj2) = georef.extract_raster_dataset(ds, mode="edge")
+        filename2 = "hdf5/belgium.comp.hdf"
+        geofile2 = util.get_wradlib_data_file(filename2)
+        ds2 = wradlib.io.open_raster(geofile2)
+        (data2, coords2, proj2) = georef.extract_raster_dataset(ds2, mode="edge")
 
     corner_gdalinfo = np.array([[3e5, 1e6], [3e5, 3e5], [1e6, 3e5], [1e6, 1e6]])
 
@@ -735,8 +734,6 @@ class TestGdal:
         ul_center = (edge_coords[0, 0] + edge_coords[1, 1]) / 2
         np.testing.assert_array_almost_equal(center_coords[0, 0], ul_center)
 
-    requires_data
-
     def test_read_gdal_projection(self):
         georef.read_gdal_projection(self.ds)
 
@@ -833,9 +830,13 @@ class TestGdal:
         data, coords, proj = georef.extract_raster_dataset(ds, mode="edge")
         assert coords.shape[-1] == 2
 
-    @pytest.mark.skipif(sys.platform.startswith("win"), reason="known break on windows")
     def test_get_raster_elevation(self):
-        georef.get_raster_elevation(self.ds, download={"region": "Eurasia"})
+        # crop file using translate to keep download sizes minimal
+        gdal.Translate(
+            "/vsimem/clip.tif", self.geofile1, projWin=[5.5, 49.5, 5.6, 49.4]
+        )
+        ds = wradlib.io.open_raster("/vsimem/clip.tif")
+        georef.get_raster_elevation(ds, download={"region": "Eurasia"})
 
     def test_get_raster_extent(self):
 
@@ -853,11 +854,10 @@ class TestGdal:
         extent = georef.get_raster_extent(self.ds2, geo=True, window=False)
         np.testing.assert_array_almost_equal(extent, self.corner_geo_gdalinfo)
 
-    @pytest.mark.skipif(sys.platform.startswith("win"), reason="known break on windows")
     def test_merge_raster_datasets(self):
         download = {"region": "Eurasia"}
         datasets = wradlib.io.dem.get_srtm(
-            [3, 4, 47, 48], merge=False, download=download
+            [5, 6, 49.4, 49.5], merge=False, download=download
         )
         georef.merge_raster_datasets(datasets)
 
@@ -939,6 +939,27 @@ class TestGetGrids:
         assert pytest.approx(phi[0]) == 45.0
         assert pytest.approx(theta[0]) == 35.25802956
 
+    @pytest.mark.parametrize(
+        "grid, origin, wgs",
+        [
+            ((450, 450), [3.58892995, 46.95258041], True),
+            ((450, 450), [-523.46216692, -4658.64472426], False),
+            ((460, 460), [3.48137612, 46.86031976], True),
+            ((460, 460), [-533.46216692, -4668.64472426], False),
+            ((900, 900), [3.58892995, 46.95258041], True),
+            ((900, 900), [-523.46216692, -4658.64472426], False),
+            ((1100, 900), [4.67593418, 46.19287861], True),
+            ((1100, 900), [-443.46216692, -4758.64472426], False),
+            ((1200, 1100), [3.5519213, 45.69587048], True),
+            ((1200, 1100), [-543.46216692, -4808.64472426], False),
+            ((1500, 1400), [2.34194262, 43.9335861], True),
+            ((1500, 1400), [-673.46216692, -5008.64472426], False),
+        ],
+    )
+    def test_grid_reference_points(self, grid, origin, wgs):
+        arr = list(georef.get_radolan_grid(grid[0], grid[1], wgs84=wgs)[0, 0])
+        assert pytest.approx(arr, origin[0])
+
 
 class TestSatellite:
     if has_data:
@@ -1169,7 +1190,7 @@ class TestVector:
             if feature:
                 geom = feature.GetGeometryRef()
                 y.append(georef.ogr_to_numpy(geom))
-        y = np.array(y)
+        y = np.array(y, dtype=object)
         for x1, y1 in zip(x, y):
             np.testing.assert_allclose(x1, y1)
 
@@ -1305,6 +1326,6 @@ class TestXarray:
 
     def test_georeference_dataset(self):
         src_da = self.da.copy()
-        src_da.drop(["x", "y", "z", "gr", "rays", "bins"])
+        src_da.drop_vars(["x", "y", "z", "gr", "rays", "bins"])
         da = georef.georeference_dataset(src_da)
         xr.testing.assert_equal(self.da, da)
